@@ -43,6 +43,7 @@
 #include "update-notifier.h"
 #include "livepatch-tray.h"
 #include "update.h"
+#include "unattended-upgrade.h"
 #include "hooks.h"
 #include "reboot.h"
 #include "uevent.h"
@@ -482,9 +483,24 @@ tray_icons_init(UpgradeNotifier *un)
    trayapplet_create(un->livepatch, un, "livepatch");
    livepatch_tray_icon_init(un->livepatch);
 
+   /* unattended upgrades icon */
+   un->unattended_upgrade = g_new0 (TrayApplet, 1);
+   trayapplet_create (un->unattended_upgrade, un, "unattended-upgrade");
+   unattended_upgrade_tray_icon_init (un->unattended_upgrade);
+
    return FALSE; // for the tray_destroyed_cb
 }
 
+static void
+tray_icons_dispose (UpgradeNotifier *un)
+{
+   if (un->unattended_upgrade)
+      unattended_upgrade_tray_icon_dispose (un->unattended_upgrade);
+
+   // TODO: other applets
+   // TODO: actually free the TrayApplet data
+}
+
 static gboolean
 system_user(UpgradeNotifier *un)
 {
@@ -700,5 +716,7 @@ main (int argc, char **argv)
 				NULL, NULL);
 	gtk_main ();
 
+	tray_icons_dispose (un);
+
 	return 0;
 }
